/* vi: expandtab:softtabstop=4:tabstop=4:cindent:cino=>4,g4,h4,+4,c1,C4,(4,u4,^-0,{2,}0
 */
/*

Copyright (c) 2008, SFB/TR-55
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

   * Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.

   * Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

#ifndef ASN1CONVENIENCE_H_
#define ASN1CONVENIENCE_H_

#include <ActionItem.h>

#define newitem(thetype,thename)\
    thetype ## _t* thename = calloc(1, sizeof(thetype ## _t))

#define newai(thename)\
    newitem(ActionItem,thename); setpl(thename, "", -1);\
    (thename)->uid = (random() % INT32_MAX)

#define newtr(thename)\
    newitem(Transaction,thename)

#define freeitem(thetype,thename)\
    ASN_STRUCT_FREE(asn_DEF_ ## thetype, thename)

#define freetr(thename)                     \
    if (thename)                            \
      {                                     \
        freeitem(Transaction, thename);    \
        thename = NULL;                     \
      }

#define addseq(root,item)\
    ASN_SEQUENCE_ADD(&((root)->list), item)

#define seqlen(root)  (root)->list.count
#define seqitem(root,num) (root)->list.array[num]

#define addkey(item,key)\
    ASN_SEQUENCE_ADD(&((item)->keys.list), )

#define setpl(actionitem,buffer,len)\
    OCTET_STRING_fromBuf(&(actionitem)->payload, (buffer), (len));

#define getpl(actionitem)   (actionitem)->payload.buf
#define lenpl(actionitem)   (actionitem)->payload.size

#define setch(thetype,root,sortof)\
    (root).present = thetype ## _PR_ ## sortof

#define isch(thetype,root,sortof)\
    ((root).present == thetype ## _PR_ ## sortof)

#define nisch(thetype,root,sortof)\
    ((root).present != thetype ## _PR_ ## sortof)

#define setchch(thetype,thethetype,root,sortof,sortofof)\
    setch(thetype,(root),sortof);\
    setch(thethetype,(root).choice.sortof,sortofof)

#define setki(actionitem,sortofof)\
    setchch(Kind,Issue,(actionitem)->kind,issue,sortofof)

#define setkr(actionitem,sortofof)\
    setchch(Kind,Reply,(actionitem)->kind,reply,sortofof)

#define der_enc(t,a,func,data) \
    der_encode(&asn_DEF_##t, a, func, data)

#define enctr(tr)\
    der_enc(Transaction,tr,consumer,NULL);

#define chch(actionitem,first,second)\
    ((actionitem)->kind.choice.first.choice.second)

#define setky(actionitem,string)\
    ASN_SEQUENCE_ADD(&((actionitem)->keys.list),\
        OCTET_STRING_new_fromBuf(&asn_DEF_IA5String,\
            (string), -1))

extern char* getky(ActionItem_t* ai, int i);

extern int haveky(ActionItem_t* ai, const char* key);
extern int findky(ActionItem_t* ai, const char* key);
extern int nhaveky(ActionItem_t* ai, const char* key);
extern int nfindky(ActionItem_t* ai, const char* key);

#endif /* ASN1CONVENIENCE_H_ */

