/* vi: expandtab:softtabstop=4:tabstop=4:cindent:cino=>4,g4,h4,+4,c1,C4,(4,u4,{0,^-0 
 */
/*

Copyright (c) 2008, SFB/TR-55
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

   * Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.

   * Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in
     the documentation and/or other materials provided with the
     distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

#ifndef SERVPROC_H_
#define SERVPROC_H_

#define SPRC 16 /**<  number of serivce processors per root card */

#define CHAR_SOF 0x55 /**< start of frame */
#define CHAR_EOF 0xAA /**< end of frame */
#define CHAR_DLE 0x10 /**< @deprecated data link escape */

#define STAT_ACCEPT 0x00 /**< command accepted successfully */
#define STAT_GERROR 0xFF /**< generic error */ 
#define STAT_FERROR 0xFE /**< framing error */ 
#define STAT_CKERR  0xFD /**< wrong frame checksum */
#define STAT_PARERR 0xFC /**< wrong parameters */
#define STAT_LNGERR 0xFB /**< reply too long */
#define STAT_BUSY   0xFA /**< service processor is busy */

#define CMD_IS_REPLY 0x80 /**< if high bit is set, cmd is a reply */

#define CMD_POWER      0x30             /**< Power control   */
#define         ACT_POWEROFF   0x00             /**<     power-off   */
#define         ACT_POWERON    0x01             /**<     power-on    */
#define         ACT_POWERCYCLE 0x02             /**<     power-cycle */
#define         ACT_REBOOT     0x03             /**<     reboot service processor */
#define         ACT_NOBOOT     0x04             /**<     power on, but do not boot */
#define CMD_READVPD    0x31             /**< Read VPD */
#define CMD_WRITEVPD   0x32             /**< Write VPD */
#define CMD_GETSENSOR  0x33             /**< Get status information */
#define         ACT_OVERALL     0x00            /**< overall information */
#define         ACT_BOOTSTAT    0x03            /**< boot status */
#define         ACT_CPUID       0x04            /**< CPU fault (cpudi) */
#define         ACT_DIMM        0x05            /**< dimm fault */
#define         ACT_VDD         0x06            /**<  VDD */
#define         ACT_OVERTEMP    0x07            /**< over temperature */
#define         ACT_THERMALERT  0x08            /**< thermal alert */
#define         ACT_CHECKSTOP   0x09            /**< checkstop */
#define         ACT_WD_EXPIRED  0x0C            /**< watchdog expired */
#define         ACT_HOST_CHKPT  0x10            /**< host checkpoint */
#define         ACT_POR_ECODE   0x11            /**< POR error code, see appendix of SP. spec */
#define         ACT_FAIL_ATT    0x12            /**< failed boot attempts */
#define         ACT_REC_FIR     0x13            /**< recoverable FIR */
#define         ACT_CPU_ATT     0x14            /**< cpu attention */
#define         ACT_FPGA_CHECK  0x15            /**< FPGA check See spec, page 18 */
#define CMD_SET_WATCHDOG    0x35        /**< set watchdog */
#define         ACT_WD_NORMAL   0x00            /**< normal reboot */
#define         ACT_WD_CHANGE   0x01            /**< change flashside */
#define CMD_BACKDOOR    0x36            /**< spi command (backdoor) */
#define CMD_SPI         0x36            /**< spi command (raw) */
#define CMD_DEBUG       0x37            /**< debug system */
#define         ACT_DEBUG_WRITE 0x01            /**< write debug data */
#define         ACT_DEBUG_READ  0x02            /**< read debug data */
#define CMD_VPD_LOG     0x38            /**< write message to VPD */
#define CMD_CLEAR_STATES    0x39        /**< cleans all states */
#define CMD_NODEID  0x41                /**< set the node ID */
#define         ACT_MAC           0x00  /**< set the mac address */
#define CMD_RD_CPLDPORTBIT  0x42        /**< read a CPLD port bit/byte */
#define CMD_WR_CPLDPORTBIT  0x43        /**< write a CPLD port bit/byte */
#define CMD_CONSOLE         0x44        /**< enable the SP console */
#define         ACT_ENABLE_CONSOLE  0x01        /**< enable the SP console */
#define         ACT_DISABLE_CONSOLE 0x00        /**< disable the SP console */
#define CMD_VERSION         0x45        /**< get the SP version */
#define CMD_TEMPERATURE     0x46        /**< read temperature sensors */
#define CMD_GET_RTC         0x47        /**< get real-time clock */
#define CMD_SET_RTC         0x48        /**< set real-time clock */

#define MAX_DATA_PAYLOAD 255   /**< Maximal length of data parameters */

#endif /* SERVPROC_H_ */

